@@ -8,6 +8,7 @@ import logging
 import inspect
 import imp
 import argparse
+import signal
 
 import tornado.ioloop
 from tornado.web import Application
@@ -190,6 +191,21 @@ class Server(object):
 
         self.initialize_assets()
 
+    def handle_signals(self, io_loop):
+        def handle(signal, frame):
+            io_loop.stop()
+
+            if io_loop is not None:
+                self.plugin_before_end(io_loop=io_loop)
+
+            logging.info('')
+            logging.info('-- %s closed by signal --' % str(signal))
+            sys.exit(1)
+
+        signal.signal(signal.SIGINT, handle)
+        signal.signal(signal.SIGTERM, handle)
+        signal.signal(signal.SIGHUP, handle)
+
     def start(self, args=None):
         if args is None:
             args = sys.argv[1:]
@@ -235,6 +251,9 @@ class Server(object):
             self.plugin_after_start(io_loop=io_loop)
 
             logging.info('-- %s started listening in %s:%d --' % (server_name, options.bind, options.port))
+
+            self.handle_signals(io_loop)
+
             io_loop.start()
         except KeyboardInterrupt:
             if io_loop is not None:
